@@ -1,19 +1,17 @@
 //! POSIX-style `*at` functions.
 
-#[cfg(any(target_os = "macos", target_os = "ios"))]
+#[cfg(any(target_os = "ios", target_os = "macos"))]
 use crate::fs::CloneFlags;
 use crate::{imp, io, path};
 #[cfg(not(any(
+    target_os = "ios",
+    target_os = "macos",
     target_os = "redox",
     target_os = "wasi",
-    target_os = "macos",
-    target_os = "ios"
 )))]
 use imp::fs::Dev;
-use imp::{
-    fs::{Access, AtFlags, Mode, OFlags, Stat},
-    time::Timespec,
-};
+use imp::fs::{Access, AtFlags, Mode, OFlags, Stat};
+use imp::time::Timespec;
 use io_lifetimes::{AsFd, BorrowedFd, OwnedFd};
 use std::ffi::{CStr, OsString};
 #[cfg(unix)]
@@ -69,7 +67,7 @@ fn _readlinkat(dirfd: BorrowedFd<'_>, path: &CStr, reuse: OsString) -> io::Resul
     // uninitialized memory, but that requires `unsafe`.
     let mut buffer = reuse.into_vec();
     buffer.clear();
-    buffer.resize(256, 0u8);
+    buffer.resize(256, 0_u8);
 
     loop {
         let nread = imp::syscalls::readlinkat(dirfd, path, &mut buffer)?;
@@ -77,10 +75,10 @@ fn _readlinkat(dirfd: BorrowedFd<'_>, path: &CStr, reuse: OsString) -> io::Resul
         let nread = nread as usize;
         assert!(nread <= buffer.len());
         if nread < buffer.len() {
-            buffer.resize(nread, 0u8);
+            buffer.resize(nread, 0_u8);
             return Ok(OsString::from_vec(buffer));
         }
-        buffer.resize(buffer.len() * 2, 0u8);
+        buffer.resize(buffer.len() * 2, 0_u8);
     }
 }
 
@@ -266,7 +264,7 @@ pub fn chmodat<P: path::Arg, Fd: AsFd>(dirfd: &Fd, path: P, mode: Mode) -> io::R
 ///  - [Apple]
 ///
 /// [Apple]: https://opensource.apple.com/source/xnu/xnu-3789.21.4/bsd/man/man2/clonefile.2.auto.html
-#[cfg(any(target_os = "macos", target_os = "ios"))]
+#[cfg(any(target_os = "ios", target_os = "macos"))]
 #[inline]
 pub fn fclonefileat<Fd: AsFd, DstFd: AsFd, P: path::Arg>(
     src: &Fd,
@@ -290,10 +288,10 @@ pub fn fclonefileat<Fd: AsFd, DstFd: AsFd, P: path::Arg>(
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/mknodat.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/mknodat.2.html
 #[cfg(not(any(
+    target_os = "ios",
+    target_os = "macos",
     target_os = "redox",
     target_os = "wasi",
-    target_os = "macos",
-    target_os = "ios"
 )))]
 #[inline]
 pub fn mknodat<P: path::Arg, Fd: AsFd>(
