@@ -8,6 +8,9 @@
     target_os = "wasi",
 )))]
 use super::conv::ret_u32;
+use super::conv::{
+    borrowed_fd, ret, ret_c_int, ret_discarded_fd, ret_off_t, ret_owned_fd, ret_ssize_t,
+};
 #[cfg(any(target_os = "android", target_os = "linux"))]
 use super::conv::{syscall_ret, syscall_ret_owned_fd, syscall_ret_ssize_t};
 #[cfg(not(any(
@@ -15,17 +18,17 @@ use super::conv::{syscall_ret, syscall_ret_owned_fd, syscall_ret_ssize_t};
     target_os = "macos",
     target_os = "netbsd",
     target_os = "openbsd",
-    target_os = "redox"
+    target_os = "redox",
 )))]
 use super::fs::Advice;
 #[cfg(not(any(
+    target_os = "ios",
+    target_os = "macos",
     target_os = "redox",
     target_os = "wasi",
-    target_os = "macos",
-    target_os = "ios"
 )))]
 use super::fs::Dev;
-#[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "openbsd")))]
+#[cfg(not(any(target_os = "netbsd", target_os = "openbsd", target_os = "redox")))]
 use super::fs::FallocateFlags;
 #[cfg(not(target_os = "wasi"))]
 use super::fs::FlockOperation;
@@ -34,64 +37,65 @@ use super::fs::ResolveFlags;
 #[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))]
 // not implemented in libc for netbsd yet
 use super::fs::StatFs;
+use super::fs::{Access, FdFlags, Mode, OFlags, Stat};
 #[cfg(all(target_os = "linux", target_env = "gnu"))]
 use super::fs::{Statx, StatxFlags};
 #[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "wasi")))]
 use super::io::PipeFlags;
-#[cfg(not(any(target_os = "wasi", target_os = "redox")))]
+use super::io::PollFd;
+#[cfg(not(any(target_os = "redox", target_os = "wasi")))]
 use super::net::{
     decode_sockaddr, AcceptFlags, AddressFamily, Protocol, RecvFlags, SendFlags, Shutdown,
     SocketAddr, SocketAddrUnix, SocketAddrV4, SocketAddrV6, SocketType,
 };
-#[cfg(any(target_os = "linux", target_os = "android", target_os = "fuchsia"))]
+#[cfg(any(target_os = "android", target_os = "fuchsia", target_os = "linux"))]
 use super::offset::libc_fallocate;
 #[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))]
 use super::offset::libc_fstatfs;
 #[cfg(not(target_os = "wasi"))]
 use super::offset::libc_mmap;
 #[cfg(not(any(
-    target_os = "netbsd",
-    target_os = "openbsd",
     target_os = "ios",
     target_os = "macos",
+    target_os = "netbsd",
+    target_os = "openbsd",
     target_os = "redox",
 )))]
 use super::offset::libc_posix_fadvise;
 #[cfg(not(any(
-    target_os = "netbsd",
-    target_os = "openbsd",
-    target_os = "ios",
-    target_os = "macos",
-    target_os = "redox",
-    target_os = "linux",
     target_os = "android",
     target_os = "fuchsia",
+    target_os = "ios",
+    target_os = "linux",
+    target_os = "macos",
+    target_os = "netbsd",
+    target_os = "openbsd",
+    target_os = "redox",
 )))]
 use super::offset::libc_posix_fallocate;
+use super::offset::{libc_fstat, libc_fstatat, libc_lseek, libc_off_t, libc_pread, libc_pwrite};
 #[cfg(target_os = "linux")]
 use super::rand::GetRandomFlags;
-use super::{
-    conv::{borrowed_fd, ret, ret_c_int, ret_discarded_fd, ret_off_t, ret_owned_fd, ret_ssize_t},
-    fs::{Access, FdFlags, Mode, OFlags, Stat},
-    io::PollFd,
-    offset::{libc_fstat, libc_fstatat, libc_lseek, libc_off_t, libc_pread, libc_pwrite},
-    time::Timespec,
-};
+use super::time::Timespec;
 #[cfg(all(target_os = "linux", target_env = "gnu"))]
 use super::{
     io::ReadWriteFlags,
     offset::{libc_preadv2, libc_pwritev2},
 };
-use crate::{
-    as_ptr,
-    io::{self, RawFd},
-};
+use crate::as_ptr;
+use crate::io::{self, RawFd};
 use errno::errno;
 use io_lifetimes::{AsFd, BorrowedFd, OwnedFd};
-#[cfg(not(any(target_os = "wasi", target_os = "fuchsia")))]
+use std::cmp::min;
+use std::convert::TryInto;
+use std::ffi::CStr;
+#[cfg(not(any(target_os = "fuchsia", target_os = "wasi")))]
 use std::ffi::OsString;
+use std::io::{IoSlice, IoSliceMut, SeekFrom};
 #[cfg(target_os = "linux")]
 use std::mem::transmute;
+use std::mem::{size_of, MaybeUninit};
+use std::os::raw::{c_int, c_void};
 #[cfg(all(unix, not(target_os = "fuchsia")))]
 use std::os::unix::ffi::OsStringExt;
 #[cfg(target_os = "wasi")]
@@ -100,14 +104,6 @@ use std::os::wasi::ffi::OsStringExt;
 use std::ptr::null_mut;
 #[cfg(not(any(target_os = "redox", target_env = "newlib")))]
 use std::sync::atomic::{AtomicUsize, Ordering};
-use std::{
-    cmp::min,
-    convert::TryInto,
-    ffi::CStr,
-    io::{IoSlice, IoSliceMut, SeekFrom},
-    mem::{size_of, MaybeUninit},
-    os::raw::{c_int, c_void},
-};
 #[cfg(not(target_os = "redox"))]
 use {
     super::conv::c_str,
@@ -472,8 +468,8 @@ pub(crate) fn utimensat(
 #[cfg(not(any(
     target_os = "android",
     target_os = "linux",
+    target_os = "redox",
     target_os = "wasi",
-    target_os = "redox"
 )))]
 pub(crate) fn chmodat(dirfd: BorrowedFd<'_>, path: &CStr, mode: Mode) -> io::Result<()> {
     unsafe {
@@ -499,7 +495,7 @@ pub(crate) fn chmodat(dirfd: BorrowedFd<'_>, path: &CStr, mode: Mode) -> io::Res
     }
 }
 
-#[cfg(any(target_os = "macos", target_os = "ios"))]
+#[cfg(any(target_os = "ios", target_os = "macos"))]
 pub(crate) fn fclonefileat(
     srcfd: BorrowedFd<'_>,
     dst_dirfd: BorrowedFd<'_>,
@@ -519,10 +515,10 @@ pub(crate) fn fclonefileat(
 }
 
 #[cfg(not(any(
+    target_os = "ios",
+    target_os = "macos",
     target_os = "redox",
     target_os = "wasi",
-    target_os = "macos",
-    target_os = "ios"
 )))]
 pub(crate) fn mknodat(dirfd: BorrowedFd<'_>, path: &CStr, mode: Mode, dev: Dev) -> io::Result<()> {
     unsafe {
@@ -738,12 +734,12 @@ pub(crate) fn fallocate(
     let offset = offset as i64;
     let len = len as i64;
 
-    #[cfg(any(target_os = "linux", target_os = "android", target_os = "fuchsia"))]
+    #[cfg(any(target_os = "android", target_os = "fuchsia", target_os = "linux"))]
     unsafe {
         ret(libc_fallocate(borrowed_fd(fd), mode.bits(), offset, len))
     }
 
-    #[cfg(not(any(target_os = "linux", target_os = "android", target_os = "fuchsia")))]
+    #[cfg(not(any(target_os = "android", target_os = "fuchsia", target_os = "linux")))]
     {
         assert!(mode.is_empty());
         let err = unsafe { libc_posix_fallocate(borrowed_fd(fd), offset, len) };
@@ -1050,13 +1046,13 @@ pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: &OwnedFd, _flags: DupFlags) ->
     dup2(fd, new)
 }
 
-#[cfg(not(any(target_os = "wasi", target_os = "fuchsia")))]
+#[cfg(not(any(target_os = "fuchsia", target_os = "wasi")))]
 pub(crate) fn ttyname(dirfd: BorrowedFd<'_>, reuse: OsString) -> io::Result<OsString> {
     // This code would benefit from having a better way to read into
     // uninitialized memory, but that requires `unsafe`.
     let mut buffer = reuse.into_vec();
     buffer.clear();
-    buffer.resize(256, 0u8);
+    buffer.resize(256, 0_u8);
 
     loop {
         match unsafe {
@@ -1066,10 +1062,10 @@ pub(crate) fn ttyname(dirfd: BorrowedFd<'_>, reuse: OsString) -> io::Result<OsSt
                 buffer.len(),
             )
         } {
-            libc::ERANGE => buffer.resize(buffer.len() * 2, 0u8),
+            libc::ERANGE => buffer.resize(buffer.len() * 2, 0_u8),
             0 => {
                 let len = buffer.iter().position(|x| *x == b'\0').unwrap();
-                buffer.resize(len, 0u8);
+                buffer.resize(len, 0_u8);
                 return Ok(OsString::from_vec(buffer));
             }
             errno => return Err(io::Error(errno)),
@@ -1556,7 +1552,7 @@ pub(crate) fn getrandom(buf: &mut [u8], flags: GetRandomFlags) -> io::Result<usi
     Ok(nread as usize)
 }
 
-#[cfg(not(any(target_os = "wasi", target_os = "redox")))]
+#[cfg(not(any(target_os = "redox", target_os = "wasi")))]
 #[inline]
 #[must_use]
 pub(crate) fn clock_getres(id: ClockId) -> Timespec {
@@ -1631,13 +1627,12 @@ pub(crate) fn clock_gettime_dynamic(id: DynamicClockId) -> io::Result<Timespec>
 }
 
 #[cfg(not(any(
-    target_os = "macos",
-    target_os = "ios",
-    target_os = "ios",
-    target_os = "redox",
-    target_os = "freebsd", // FreeBSD 12 has clock_nanosleep, but libc targets FreeBSD 11.
-    target_os = "openbsd",
     target_os = "emscripten",
+    target_os = "freebsd", // FreeBSD 12 has clock_nanosleep, but libc targets FreeBSD 11.
+    target_os = "ios",
+    target_os = "macos",
+    target_os = "openbsd",
+    target_os = "redox",
     target_os = "wasi",
 )))]
 #[inline]
@@ -1657,13 +1652,12 @@ pub(crate) fn clock_nanosleep_relative(id: ClockId, request: &Timespec) -> Nanos
 }
 
 #[cfg(not(any(
-    target_os = "macos",
-    target_os = "ios",
-    target_os = "ios",
-    target_os = "redox",
     target_os = "freebsd", // FreeBSD 12 has clock_nanosleep, but libc targets FreeBSD 11.
-    target_os = "openbsd",
     target_os = "emscripten",
+    target_os = "ios",
+    target_os = "macos",
+    target_os = "openbsd",
+    target_os = "redox",
     target_os = "wasi",
 )))]
 #[inline]
