@@ -59,19 +59,15 @@
 #![allow(unsafe_code)]
 
 use super::super::syscalls::{epoll_add, epoll_create, epoll_del, epoll_mod, epoll_wait};
-use crate::{
-    io,
-    io::{AsRawFd, FromRawFd, IntoRawFd, RawFd},
-};
+use crate::io;
+use crate::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
 use bitflags::bitflags;
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
-use std::{
-    fmt,
-    marker::PhantomData,
-    ops::Deref,
-    os::raw::{c_int, c_uint},
-    ptr::null,
-};
+use std::fmt;
+use std::marker::PhantomData;
+use std::ops::Deref;
+use std::os::raw::{c_int, c_uint};
+use std::ptr::null;
 
 bitflags! {
     /// `EPOLL_*` for use with [`Epoll::new`].
@@ -254,8 +250,8 @@ impl<'context, T: AsFd + IntoFd + FromFd> Context for Owning<'context, T> {
 
     #[inline]
     fn release(&self, target: Ref<'_, Self::Target>) -> Self::Data {
-        // The file descriptor was held by the kernel epoll object and is now
-        // being released, so we can create a new `OwnedFd` that assumes
+        // Safety: The file descriptor was held by the kernel epoll object and
+        // is now being released, so we can create a new `OwnedFd` that assumes
         // ownership.
         let raw_fd = target.consume().as_raw_fd();
         unsafe { T::from_fd(OwnedFd::from_raw_fd(raw_fd)) }
