@@ -9,12 +9,10 @@
 //! functions.
 #![allow(unsafe_code)]
 
-use super::{
-    arch::asm::syscall2,
-    conv::ret,
-    time::{ClockId, DynamicClockId, Timespec},
-    vdso,
-};
+use super::arch::asm::syscall2;
+use super::conv::ret;
+use super::time::{ClockId, DynamicClockId, Timespec};
+use super::vdso;
 use crate::io;
 use cstr::cstr;
 use linux_raw_sys::general::{__NR_clock_gettime, __kernel_clockid_t, __kernel_timespec};
@@ -22,11 +20,10 @@ use linux_raw_sys::general::{__NR_clock_gettime, __kernel_clockid_t, __kernel_ti
 use linux_raw_sys::{
     general::timespec as __kernel_old_timespec, v5_4::general::__NR_clock_gettime64,
 };
-use std::{
-    mem::{transmute, MaybeUninit},
-    os::raw::c_int,
-    sync::atomic::{AtomicUsize, Ordering::Relaxed},
-};
+use std::mem::{transmute, MaybeUninit};
+use std::os::raw::c_int;
+use std::sync::atomic::AtomicUsize;
+use std::sync::atomic::Ordering::Relaxed;
 
 #[inline]
 pub(crate) fn clock_gettime(which_clock: ClockId) -> __kernel_timespec {
@@ -44,30 +41,30 @@ pub(crate) fn clock_gettime(which_clock: ClockId) -> __kernel_timespec {
 
 #[inline]
 pub(crate) fn clock_gettime_dynamic(which_clock: DynamicClockId) -> io::Result<Timespec> {
+    let id = match which_clock {
+        DynamicClockId::Known(id) => id as __kernel_clockid_t,
+
+        DynamicClockId::Dynamic(fd) => {
+            // See `FD_TO_CLOCKID` in Linux's `clock_gettime` documentation.
+            use crate::io::AsRawFd;
+            const CLOCKFD: i32 = 3;
+            ((!fd.as_raw_fd() << 3) | CLOCKFD) as __kernel_clockid_t
+        }
+
+        DynamicClockId::RealtimeAlarm => {
+            linux_raw_sys::v5_4::general::CLOCK_REALTIME_ALARM as __kernel_clockid_t
+        }
+        DynamicClockId::Tai => linux_raw_sys::v5_4::general::CLOCK_TAI as __kernel_clockid_t,
+        DynamicClockId::Boottime => {
+            linux_raw_sys::v5_4::general::CLOCK_BOOTTIME as __kernel_clockid_t
+        }
+        DynamicClockId::BoottimeAlarm => {
+            linux_raw_sys::v5_4::general::CLOCK_BOOTTIME_ALARM as __kernel_clockid_t
+        }
+    };
+
     unsafe {
         let mut timespec = MaybeUninit::<Timespec>::uninit();
-        let id = match which_clock {
-            DynamicClockId::Known(id) => id as __kernel_clockid_t,
-
-            DynamicClockId::Dynamic(fd) => {
-                // See `FD_TO_CLOCKID` in Linux's `clock_gettime` documentation.
-                use crate::io::AsRawFd;
-                const CLOCKFD: i32 = 3;
-                ((!fd.as_raw_fd() << 3) | CLOCKFD) as __kernel_clockid_t
-            }
-
-            DynamicClockId::RealtimeAlarm => {
-                linux_raw_sys::v5_4::general::CLOCK_REALTIME_ALARM as __kernel_clockid_t
-            }
-            DynamicClockId::Tai => linux_raw_sys::v5_4::general::CLOCK_TAI as __kernel_clockid_t,
-            DynamicClockId::Boottime => {
-                linux_raw_sys::v5_4::general::CLOCK_BOOTTIME as __kernel_clockid_t
-            }
-            DynamicClockId::BoottimeAlarm => {
-                linux_raw_sys::v5_4::general::CLOCK_BOOTTIME_ALARM as __kernel_clockid_t
-            }
-        };
-
         let callee = match transmute(CLOCK_GETTIME.load(Relaxed)) {
             Some(callee) => callee,
             None => init_clock_gettime(),
@@ -79,9 +76,11 @@ pub(crate) fn clock_gettime_dynamic(which_clock: DynamicClockId) -> io::Result<T
 
 #[cfg(target_arch = "x86")]
 pub(crate) mod x86_via_vdso {
-    use super::{super::arch::asm, transmute, Relaxed};
+    use super::super::arch::asm;
+    use super::{transmute, Relaxed};
 
     #[inline]
+    #[must_use]
     pub(crate) unsafe fn syscall0(nr: u32) -> usize {
         let callee = match transmute(super::SYSCALL.load(Relaxed)) {
             Some(callee) => callee,
@@ -91,6 +90,7 @@ pub(crate) mod x86_via_vdso {
     }
 
     #[inline]
+    #[must_use]
     pub(crate) unsafe fn syscall1(nr: u32, a0: usize) -> usize {
         let callee = match transmute(super::SYSCALL.load(Relaxed)) {
             Some(callee) => callee,
@@ -109,6 +109,7 @@ pub(crate) mod x86_via_vdso {
     }
 
     #[inline]
+    #[must_use]
     pub(crate) unsafe fn syscall2(nr: u32, a0: usize, a1: usize) -> usize {
         let callee = match transmute(super::SYSCALL.load(Relaxed)) {
             Some(callee) => callee,
@@ -118,6 +119,7 @@ pub(crate) mod x86_via_vdso {
     }
 
     #[inline]
+    #[must_use]
     pub(crate) unsafe fn syscall3(nr: u32, a0: usize, a1: usize, a2: usize) -> usize {
         let callee = match transmute(super::SYSCALL.load(Relaxed)) {
             Some(callee) => callee,
@@ -127,6 +129,7 @@ pub(crate) mod x86_via_vdso {
     }
 
     #[inline]
+    #[must_use]
     pub(crate) unsafe fn syscall4(nr: u32, a0: usize, a1: usize, a2: usize, a3: usize) -> usize {
         let callee = match transmute(super::SYSCALL.load(Relaxed)) {
             Some(callee) => callee,
@@ -136,6 +139,7 @@ pub(crate) mod x86_via_vdso {
     }
 
     #[inline]
+    #[must_use]
     pub(crate) unsafe fn syscall5(
         nr: u32,
         a0: usize,
@@ -152,6 +156,7 @@ pub(crate) mod x86_via_vdso {
     }
 
     #[inline]
+    #[must_use]
     pub(crate) unsafe fn syscall6(
         nr: u32,
         a0: usize,
@@ -170,13 +175,12 @@ pub(crate) mod x86_via_vdso {
 
     // With the indirect call, it isn't meaningful to do a separate
     // `_readonly` optimization.
-    pub(crate) use syscall0 as syscall0_readonly;
-    pub(crate) use syscall1 as syscall1_readonly;
-    pub(crate) use syscall2 as syscall2_readonly;
-    pub(crate) use syscall3 as syscall3_readonly;
-    pub(crate) use syscall4 as syscall4_readonly;
-    pub(crate) use syscall5 as syscall5_readonly;
-    pub(crate) use syscall6 as syscall6_readonly;
+    pub(crate) use {
+        syscall0 as syscall0_readonly, syscall1 as syscall1_readonly,
+        syscall2 as syscall2_readonly, syscall3 as syscall3_readonly,
+        syscall4 as syscall4_readonly, syscall5 as syscall5_readonly,
+        syscall6 as syscall6_readonly,
+    };
 }
 
 type ClockGettimeType = unsafe extern "C" fn(c_int, *mut Timespec) -> c_int;
@@ -184,15 +188,19 @@ type ClockGettimeType = unsafe extern "C" fn(c_int, *mut Timespec) -> c_int;
 pub(super) type SyscallType =
     unsafe extern "C" fn(u32, usize, usize, usize, usize, usize, usize) -> usize;
 
-unsafe fn init_clock_gettime() -> ClockGettimeType {
+fn init_clock_gettime() -> ClockGettimeType {
     init();
-    transmute(CLOCK_GETTIME.load(Relaxed))
+    // Safety: Load the function address from static storage that we
+    // just initialized.
+    unsafe { transmute(CLOCK_GETTIME.load(Relaxed)) }
 }
 
 #[cfg(target_arch = "x86")]
-unsafe fn init_syscall() -> SyscallType {
+fn init_syscall() -> SyscallType {
     init();
-    transmute(SYSCALL.load(Relaxed))
+    // Safety: Load the function address from static storage that we
+    // just initialized.
+    unsafe { transmute(SYSCALL.load(Relaxed)) }
 }
 
 static mut CLOCK_GETTIME: AtomicUsize = AtomicUsize::new(0);
@@ -257,24 +265,25 @@ extern "C" {
     ) -> usize;
 }
 
-unsafe fn init() {
-    CLOCK_GETTIME
-        .compare_exchange(
-            0,
-            posish_clock_gettime_via_syscall as ClockGettimeType as usize,
-            Relaxed,
-            Relaxed,
-        )
-        .ok();
-    #[cfg(target_arch = "x86")]
-    SYSCALL
-        .compare_exchange(
-            0,
-            transmute(posish_int_0x80 as SyscallType),
-            Relaxed,
-            Relaxed,
-        )
-        .ok();
+fn init() {
+    // Safety: Store default function addresses in static storage so that if we
+    // end up making any system calls while we read the vDSO, they'll work.
+    // If the memory happens to already be initialized, this is redundant, but
+    // not harmful.
+    unsafe {
+        CLOCK_GETTIME
+            .compare_exchange(
+                0,
+                posish_clock_gettime_via_syscall as ClockGettimeType as usize,
+                Relaxed,
+                Relaxed,
+            )
+            .ok();
+        #[cfg(target_arch = "x86")]
+        SYSCALL
+            .compare_exchange(0, posish_int_0x80 as SyscallType as usize, Relaxed, Relaxed)
+            .ok();
+    }
 
     if let Some(vdso) = vdso::Vdso::new() {
         #[cfg(target_arch = "x86_64")]
@@ -287,13 +296,19 @@ unsafe fn init() {
         let ptr = vdso.sym(cstr!("LINUX_4.15"), cstr!("__kernel_clock_gettime"));
 
         assert!(!ptr.is_null());
-        CLOCK_GETTIME.store(ptr as usize, Relaxed);
 
-        #[cfg(target_arch = "x86")]
-        {
-            let ptr = vdso.sym(cstr!("LINUX_2.5"), cstr!("__kernel_vsyscall"));
-            assert!(!ptr.is_null());
-            SYSCALL.store(ptr as usize, Relaxed);
+        // Safety: Store the computed function addresses in static storage
+        // so that we don't need to compute it again (but if we do, it doesn't
+        // hurt anything).
+        unsafe {
+            CLOCK_GETTIME.store(ptr as usize, Relaxed);
+
+            #[cfg(target_arch = "x86")]
+            {
+                let ptr = vdso.sym(cstr!("LINUX_2.5"), cstr!("__kernel_vsyscall"));
+                assert!(!ptr.is_null());
+                SYSCALL.store(ptr as usize, Relaxed);
+            }
         }
     }
 }
