@@ -1,7 +1,5 @@
 //! I/O operations.
 
-#![allow(unsafe_code)]
-
 use crate::imp;
 #[cfg(not(target_os = "wasi"))]
 use imp::io::Tcflag;
@@ -13,6 +11,7 @@ pub(crate) use std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
 #[cfg(target_os = "wasi")]
 pub(crate) use std::os::wasi::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
 
+mod close;
 mod error;
 #[cfg(any(target_os = "android", target_os = "linux"))]
 mod eventfd;
@@ -31,6 +30,7 @@ mod stdio;
 #[cfg(any(target_os = "android", target_os = "linux"))]
 mod userfaultfd;
 
+pub use close::close;
 pub use error::{Error, Result};
 #[cfg(any(target_os = "android", target_os = "linux"))]
 pub use eventfd::{eventfd, EventfdFlags};
@@ -38,9 +38,9 @@ pub use eventfd::{eventfd, EventfdFlags};
 pub use fd::ioctl_fionread;
 #[cfg(not(target_os = "redox"))]
 pub use fd::is_read_write;
-#[cfg(all(libc, not(any(target_os = "wasi", target_os = "fuchsia"))))]
+pub use fd::isatty;
+#[cfg(all(libc, not(any(target_os = "fuchsia", target_os = "wasi"))))]
 pub use fd::ttyname;
-pub use fd::{close, isatty};
 #[cfg(not(target_os = "wasi"))]
 pub use fd::{dup, dup2, dup2_with, DupFlags};
 #[cfg(any(target_os = "android", target_os = "linux"))]
@@ -82,9 +82,17 @@ pub use imp::io::Winsize;
 #[cfg(any(linux_raw, all(libc, not(target_os = "wasi"))))]
 pub const ICANON: Tcflag = imp::io::ICANON;
 
-/// `PIPE_BUF`
+/// `PIPE_BUF`—The maximum length at which writes to a pipe are atomic.
+///
+/// # References
+///
+///  - [Linux]
+///  - [POSIX]
+///
+/// [Linux]: https://man7.org/linux/man-pages/man7/pipe.7.html
+/// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/write.html
 #[cfg(any(
     linux_raw,
-    all(libc, not(any(target_os = "wasi", target_os = "redox")))
+    all(libc, not(any(target_os = "redox", target_os = "wasi")))
 ))]
 pub const PIPE_BUF: usize = imp::io::PIPE_BUF;
