@@ -46,6 +46,7 @@
 #![cfg_attr(linux_raw, deny(unsafe_code))]
 #![cfg_attr(linux_raw_inline_asm, feature(asm))]
 #![cfg_attr(const_fn_union, feature(const_fn_union))]
+#![cfg_attr(rustc_attrs, feature(rustc_attrs))]
 #![cfg_attr(target_os = "wasi", feature(wasi_ext))]
 #![cfg_attr(
     all(linux_raw_inline_asm, target_arch = "x86"),
@@ -60,7 +61,7 @@ mod imp;
 
 pub mod fs;
 pub mod io;
-#[cfg(not(any(target_os = "wasi", target_os = "redox")))] // WASI doesn't support `net` yet.
+#[cfg(not(any(target_os = "redox", target_os = "wasi")))] // WASI doesn't support `net` yet.
 pub mod net;
 pub mod path;
 pub mod process;
