@@ -2,6 +2,6 @@ use posish::rand::{getrandom, GetRandomFlags};
 
 #[test]
 fn test_getrandom() {
-    let mut buf = [0u8; 256];
+    let mut buf = [0_u8; 256];
     let _ = getrandom(&mut buf, GetRandomFlags::empty());
 }
